﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using Infragistics.UltraChart.Shared.Styles;
using Infragistics.UltraChart.Resources.Appearance;
using Infragistics.UltraChart.Core.Layers;
using Infragistics.UltraChart.Core.Primitives;
using System.Diagnostics;

namespace UltraChartHideWeekend
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();

            DataTable dt = new DataTable();
            dt.Columns.Add("Date", typeof(DateTime));
            dt.Columns.Add("Value", typeof(double));

            Random rnd = new Random();
            for (int i = 0; i < 20; i++)
            {
                if (DateTime.Today.AddDays(i).DayOfWeek == DayOfWeek.Saturday || DateTime.Today.AddDays(i).DayOfWeek == DayOfWeek.Sunday)
                {
                    dt.Rows.Add(DateTime.Today.AddDays(i), null);
                }
                else
                {
                    dt.Rows.Add(DateTime.Today.AddDays(i), rnd.Next(100));
                }
            }



            this.ultraChart1.ChartType = ChartType.Composite;

            ChartArea area = new ChartArea();
            this.ultraChart1.CompositeChart.ChartAreas.Add(area);

            //Create  Y axis
            AxisItem axisY = new AxisItem();
            axisY.Extent = 20;
            axisY.DataType = AxisDataType.Numeric;
            axisY.Labels.ItemFormatString = "<DATA_VALUE:##.##>";
            axisY.OrientationType = AxisNumber.Y_Axis;
            axisY.LineColor = Color.Blue;
            area.Axes.Add(axisY);


            //Create X axis - time axis
            AxisItem axisX = new AxisItem();
            axisX.DataType = AxisDataType.Time;
            axisX.Extent = 100;
            axisX.Labels.ItemFormat = AxisItemLabelFormat.ItemLabel;
            axisX.OrientationType = AxisNumber.X_Axis;
            axisX.ScrollScale.Visible = true;
            axisX.Labels.Orientation = TextOrientation.VerticalLeftFacing;
            axisX.LineColor = Color.Blue;
            axisX.TickmarkStyle = AxisTickStyle.DataInterval;
            axisX.TimeAxisStyle.TimeAxisStyle = RulerGenre.Discrete;
            area.Axes.Add(axisX);

            ChartLayerAppearance myColumnLayer = new ChartLayerAppearance();
            myColumnLayer.ChartType = ChartType.LineChart;
            myColumnLayer.ChartArea = area;


            //Create series1
            NumericTimeSeries series1 = new NumericTimeSeries();
            series1.Label = "test";
            series1.PEs.Add(new PaintElement(Color.Red));
            series1.DataBind(dt, "Date", "Value");

            myColumnLayer.Series.Add(series1);
            ultraChart1.CompositeChart.Series.Add(series1);
            myColumnLayer.AxisX = axisX;
            myColumnLayer.AxisY = axisY;
            this.ultraChart1.CompositeChart.ChartLayers.Add(myColumnLayer);

        }

        private void ultraChart1_FillSceneGraph(object sender, Infragistics.UltraChart.Shared.Events.FillSceneGraphEventArgs e)
        {
            List<Primitive> list = new List<Primitive>();

            foreach (Primitive pr in e.SceneGraph)
            {
                if (pr.Row != -1 && pr.Column != -1 && pr.GetType() == typeof(Polyline) && Convert.ToInt32(((Polyline)pr).points[1].Value) == 0
                    && Convert.ToInt32(((Polyline)pr).points[2].Value) == 0)
                {
                    pr.GetPrimitives().Clear();
                }

                if (pr.GetType() == typeof(Text))
                {
                    DateTime dtime;
                    DateTime.TryParse(((Text)pr).GetTextString(), out dtime);
                    if (dtime.DayOfWeek == DayOfWeek.Sunday || dtime.DayOfWeek == DayOfWeek.Saturday)
                    {
                        list.Add(pr);
                    }
                }
            }

            foreach (Primitive it in list)
            {
                e.SceneGraph.Remove(it);
            }
        }
    }
}
